require 'csv'

module Metrics
  module_function

  DATA_FILE = 'releases.csv'

  def release_data
    return CSV.read(DATA_FILE)
  end

  def release_year(release_array)
    date_string = release_array.first
    return date_string.split('/').last
  end

  def data_in_year(year)
    return release_data.select { |release_array| release_year(release_array) == year }
  end

  def releases_in_year(year)
    return data_in_year(year).count
  end

  def releases_per_day_in_year(year)
    # use a decimal so that division includes the decimal
    days_in_year = 365.0
    days_in_year = 366.0 if Date.new(year.to_i).leap?
    return releases_in_year(year) / days_in_year
  end

  def releases_per_week_in_year(year)
    return releases_per_day_in_year(year) * 7
  end

  def releases_of_project_in_year(year, project)
    project_releases = data_in_year(year).select { |release_array| release_array.include? project }
    return project_releases.count
  end

  def pe_releases_in_year(year)
    return releases_of_project_in_year(year, 'Puppet Enterprise')
  end

  def foss_releases_in_year(year)
    return releases_in_year(year) - pe_releases_in_year(year)
  end
end
